@@ -3,24 +3,22 @@
 // tcpSocket.h                Created on: 4 June 2010
 //                            Author    : Duncan Grisby
 //
-//    Copyright (C) 2010-2011 Apasphere Ltd.
+//    Copyright (C) 2010-2018 Apasphere Ltd.
 //
 //    This file is part of the omniORB library
 //
 //    The omniORB library is free software; you can redistribute it and/or
-//    modify it under the terms of the GNU Library General Public
+//    modify it under the terms of the GNU Lesser General Public
 //    License as published by the Free Software Foundation; either
-//    version 2 of the License, or (at your option) any later version.
+//    version 2.1 of the License, or (at your option) any later version.
 //
 //    This library is distributed in the hope that it will be useful,
 //    but WITHOUT ANY WARRANTY; without even the implied warranty of
 //    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-//    Library General Public License for more details.
+//    Lesser General Public License for more details.
 //
-//    You should have received a copy of the GNU Library General Public
-//    License along with this library; if not, write to the Free
-//    Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-//    02111-1307, USA
+//    You should have received a copy of the GNU Lesser General Public
+//    License along with this library. If not, see http://www.gnu.org/licenses/
 //
 //
 // Description:
@@ -37,7 +35,7 @@
 ////////////////////////////////////////////////////////////////////////
 //  Platform feature selection
 
-#if !defined(OMNI_DISABLE_IPV6) && defined(HAVE_STRUCT_SOCKADDR_IN6) && defined(HAVE_STRUCT_SOCKADDR_STORAGE) && defined(HAVE_GETADDRINFO) && defined(HAVE_GETNAMEINFO)
+#if !defined(OMNI_DISABLE_IPV6) && defined(OMNI_HAVE_STRUCT_SOCKADDR_IN6) && defined(OMNI_HAVE_STRUCT_SOCKADDR_STORAGE) && defined(OMNI_HAVE_GETADDRINFO) && defined(OMNI_HAVE_GETNAMEINFO)
 #  define OMNI_SUPPORT_IPV6
 #  define OMNI_SOCKADDR_STORAGE sockaddr_storage
 #else
@@ -49,15 +47,10 @@
 #define OMNI_IPV6_SOCKETS_ACCEPT_IPV4_CONNECTIONS
 #define OMNIORB_HOSTNAME_MAX 512
 
-#ifdef HAVE_POLL
+#ifdef OMNI_HAVE_POLL
 #   define USE_POLL
 #endif
 
-// Darwin implementation of poll() appears to be broken
-#if defined(__darwin__)
-#   undef USE_POLL
-#endif
-
 #if defined(__hpux__)
 #   if __OSVERSION__ < 11
 #       undef USE_POLL
@@ -104,6 +97,7 @@
 #  define CLOSESOCKET(sock)    closesocket(sock)
 #  define SHUTDOWNSOCKET(sock) ::shutdown(sock,2)
 #  define ERRNO                ::WSAGetLastError()
+#  define SET_ERRNO(v)         ::WSASetLastError(v)
 #  define RC_EINPROGRESS       WSAEWOULDBLOCK
 #  define RC_EINTR             WSAEINTR
 #  define RC_EBADF             WSAENOTSOCK
@@ -132,7 +126,6 @@
 #  include <unistd.h>
 #  include <sys/types.h>
 #  include <errno.h>
-#  include <libcWrapper.h>
 
 #  if defined(USE_POLL)
 #    include <poll.h>
@@ -177,6 +170,7 @@ extern "C" int select (int,fd_set*,fd_set*,fd_set*,struct timeval *);
 #  endif
 
 #  define ERRNO              errno
+#  define SET_ERRNO(v)       errno = v
 #  define RC_EINTR           EINTR
 #  define RC_EINPROGRESS     EINPROGRESS
 #  if defined (__vxWorks__)
@@ -211,13 +205,15 @@ typedef int SocketHandle_t;
 class tcpSocket {
 public:
 
-  static SocketHandle_t Bind(const char*   	      host,
-			     CORBA::UShort 	      port_min,
-			     CORBA::UShort 	      port_max,
-			     const char*   	      transport_type,
-			     char*&  	              bound_host,
-			     CORBA::UShort&           bound_port,
-			     orbServer::EndpointList& endpoints);
+  static SocketHandle_t Bind(const char*              host,
+                             CORBA::UShort            port_min,
+                             CORBA::UShort            port_max,
+                             const char*              transport_type,
+                             char*&                   bound_host,
+                             CORBA::UShort&           bound_port,
+                             orbServer::EndpointList& endpoints,
+                             const char*              uri_prefix  = 0,
+                             const char*              path_suffix = 0);
   // Create a socket and bind() and listen().
   //
   // If host is null or empty string, bind to all interfaces;
@@ -239,13 +235,20 @@ public:
   //
   // endpoints is populated with all the endpoints that result from
   // the socket.
+  //
+  // If non-zero, uri_prefix is used as the prefix of URIs added to
+  // endpoints; if zero, transport_type is used as the prefix.
+  // 
+  // If non-zero, path_suffix is a path to append to the endpoint
+  // URIs.
 
 
-  static SocketHandle_t Connect(const char*   	   host,
-				CORBA::UShort 	   port,
-				const omni_time_t& deadline,
-				CORBA::ULong  	   strand_flags,
-				CORBA::Boolean&    timed_out);
+  static SocketHandle_t Connect(const char*        host,
+                                CORBA::UShort      port,
+                                const omni_time_t& deadline,
+                                CORBA::ULong       strand_flags,
+                                const char*        transport_type,
+                                CORBA::Boolean&    timed_out);
   // Connect to specified host and port.
   //
   // If deadline is set, connect attempt can time out.
@@ -259,7 +262,7 @@ public:
 
   static inline void
   logConnectFailure(const char*            message,
-		    LibcWrapper::AddrInfo* ai)
+                    LibcWrapper::AddrInfo* ai)
   {
     if (omniORB::trace(25)) {
       omniORB::logger log;
@@ -268,7 +271,7 @@ public:
       
       CORBA::UShort port = addrToPort(ai->addr());
       if (port)
-	log << ":" << port;
+        log << ":" << port;
 
       log << "\n";
     }
@@ -276,36 +279,36 @@ public:
 
   static inline void
   logConnectFailure(const char*   message,
-		    const char*   host,
-		    CORBA::UShort port=0)
+                    const char*   host,
+                    CORBA::UShort port=0)
   {
     if (omniORB::trace(25)) {
       omniORB::logger log;
       log << message << ": " << host;
       if (port)
-	log << ":" << port;
+        log << ":" << port;
       log << "\n";
     }
   }
 
 
   static inline int setAndCheckTimeout(const omni_time_t& deadline,
-				       struct timeval&    t)
+                                       struct timeval&    t)
   {
     if (deadline) {
       if (setTimeout(deadline, t)) {
         // Already timed out.
-	return 1;
+        return 1;
       }
 #if defined(USE_FAKE_INTERRUPTABLE_RECV)
-      if (t.tv_sec > orbParameters::scanGranularity) {
-	t.tv_sec = orbParameters::scanGranularity;
+      if (t.tv_sec > (time_t)orbParameters::scanGranularity) {
+        t.tv_sec = (time_t)orbParameters::scanGranularity;
       }
 #endif
     }
     else {
 #if defined(USE_FAKE_INTERRUPTABLE_RECV)
-      t.tv_sec = orbParameters::scanGranularity;
+      t.tv_sec  = (time_t)orbParameters::scanGranularity;
       t.tv_usec = 0;
 #else
       t.tv_sec = t.tv_usec = 0;
@@ -330,6 +333,12 @@ public:
       rc = RC_SOCKET_ERROR;
     }
 #else
+
+#  if !defined(__WIN32__)
+    if (sock >= FD_SETSIZE)
+      return RC_SOCKET_ERROR;
+#  endif
+
     fd_set fds, efds;
     FD_ZERO(&fds);
     FD_ZERO(&efds);
@@ -337,7 +346,7 @@ public:
     FD_SET(sock,&efds);
     struct timeval* tp = &t;
     if (t.tv_sec == 0 && t.tv_usec == 0) tp = 0;
-    rc = select(sock+1, 0, &fds, &efds, tp);
+    rc = select((int)sock+1, 0, &fds, &efds, tp);
 #endif
     return rc;
   }
@@ -357,6 +366,12 @@ public:
       rc = RC_SOCKET_ERROR;
     }
 #else
+
+#  if !defined(__WIN32__)
+    if (sock >= FD_SETSIZE)
+      return RC_SOCKET_ERROR;
+#  endif
+
     fd_set fds, efds;
     FD_ZERO(&fds);
     FD_ZERO(&efds);
@@ -364,7 +379,7 @@ public:
     FD_SET(sock,&efds);
     struct timeval* tp = &t;
     if (t.tv_sec == 0 && t.tv_usec == 0) tp = 0;
-    rc = select(sock+1, &fds, 0, &efds, tp);
+    rc = select((int)sock+1, &fds, 0, &efds, tp);
 #endif
     return rc;
   }
