@@ -9,19 +9,17 @@
 //    This file is part of the omniORB library
 //
 //    The omniORB library is free software; you can redistribute it and/or
-//    modify it under the terms of the GNU Library General Public
+//    modify it under the terms of the GNU Lesser General Public
 //    License as published by the Free Software Foundation; either
-//    version 2 of the License, or (at your option) any later version.
+//    version 2.1 of the License, or (at your option) any later version.
 //
 //    This library is distributed in the hope that it will be useful,
 //    but WITHOUT ANY WARRANTY; without even the implied warranty of
 //    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-//    Library General Public License for more details.
+//    Lesser General Public License for more details.
 //
-//    You should have received a copy of the GNU Library General Public
-//    License along with this library; if not, write to the Free
-//    Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-//    02111-1307, USA
+//    You should have received a copy of the GNU Lesser General Public
+//    License along with this library. If not, see http://www.gnu.org/licenses/
 //
 //
 // Description:
@@ -169,6 +167,19 @@ OMNI_NAMESPACE_BEGIN(omni)
 #define OMNIORBMinorCode_128 OMNIORBMinorCode(128)
 #define OMNIORBMinorCode_129 OMNIORBMinorCode(129)
 #define OMNIORBMinorCode_130 OMNIORBMinorCode(130)
+#define OMNIORBMinorCode_131 OMNIORBMinorCode(131)
+#define OMNIORBMinorCode_132 OMNIORBMinorCode(132)
+#define OMNIORBMinorCode_133 OMNIORBMinorCode(133)
+#define OMNIORBMinorCode_134 OMNIORBMinorCode(134)
+#define OMNIORBMinorCode_135 OMNIORBMinorCode(135)
+#define OMNIORBMinorCode_136 OMNIORBMinorCode(136)
+#define OMNIORBMinorCode_137 OMNIORBMinorCode(137)
+#define OMNIORBMinorCode_138 OMNIORBMinorCode(138)
+#define OMNIORBMinorCode_139 OMNIORBMinorCode(139)
+#define OMNIORBMinorCode_140 OMNIORBMinorCode(140)
+#define OMNIORBMinorCode_141 OMNIORBMinorCode(141)
+#define OMNIORBMinorCode_142 OMNIORBMinorCode(142)
+#define OMNIORBMinorCode_143 OMNIORBMinorCode(143)
 
 #define OMNI_COMMA ,
 #define DeclareValue(name,value) name = value
@@ -258,7 +269,10 @@ code( BAD_PARAM_SequenceIsTooLong            , OMNIORBMinorCode_101 ) sep \
 code( BAD_PARAM_WrongUnionMemberSelected     , OMNIORBMinorCode_107 ) sep \
 code( BAD_PARAM_InvalidFixedPointLimits      , OMNIORBMinorCode_109 ) sep \
 code( BAD_PARAM_AttemptToMarshalAbstractValue, OMNIORBMinorCode_115 ) sep \
-code( BAD_PARAM_InvalidPollerType            , OMNIORBMinorCode_127 )
+code( BAD_PARAM_InvalidPollerType            , OMNIORBMinorCode_127 ) sep \
+code( BAD_PARAM_PerThreadTimeoutWithNoCurrent, OMNIORBMinorCode_131 ) sep \
+code( BAD_PARAM_InvalidFile                  , OMNIORBMinorCode_139 ) sep \
+code( BAD_PARAM_InvalidKey                   , OMNIORBMinorCode_140 )
 
 enum BAD_PARAM_minor {
   DECLARE_BAD_PARAM_minors(DeclareValue,OMNI_COMMA)
@@ -319,6 +333,17 @@ enum INV_OBJREF_minor {
 };
 
 
+// NO_PERMISSION
+#define DECLARE_NO_PERMISSION_minors(code,sep) \
+\
+code( NO_PERMISSION_UnknownClient     , OMNIORBMinorCode_141 ) sep \
+code( NO_PERMISSION_ProxyRequiresAuth , OMNIORBMinorCode_142 )
+
+enum NO_PERMISSION_minor {
+  DECLARE_NO_PERMISSION_minors(DeclareValue,OMNI_COMMA)
+};
+
+
 // MARSHAL
 #define DECLARE_MARSHAL_minors(code,sep) \
 \
@@ -352,7 +377,13 @@ code( MARSHAL_InvalidChunkedEncoding          , OMNIORBMinorCode_111 ) sep \
 code( MARSHAL_InvalidValueTag                 , OMNIORBMinorCode_112 ) sep \
 code( MARSHAL_NoRepoIdInValueType             , OMNIORBMinorCode_113 ) sep \
 code( MARSHAL_TypeIsNotAValueType             , OMNIORBMinorCode_114 ) sep \
-code( MARSHAL_InvalidCompressedData           , OMNIORBMinorCode_128 )
+code( MARSHAL_InvalidCompressedData           , OMNIORBMinorCode_128 ) sep \
+code( MARSHAL_HTTPBufferFull                  , OMNIORBMinorCode_132 ) sep \
+code( MARSHAL_HTTPHeaderInvalid               , OMNIORBMinorCode_133 ) sep \
+code( MARSHAL_HTTPChunkInvalid                , OMNIORBMinorCode_134 ) sep \
+code( MARSHAL_InvalidBase64Data               , OMNIORBMinorCode_136 ) sep \
+code( MARSHAL_InvalidEncryptedData            , OMNIORBMinorCode_137 ) sep \
+code( MARSHAL_InvalidGIOPMessage              , OMNIORBMinorCode_143 )
 
 enum MARSHAL_minor {
   DECLARE_MARSHAL_minors(DeclareValue,OMNI_COMMA)
@@ -470,7 +501,8 @@ code( BAD_INV_ORDER_ArgumentsNotCalled            , OMNIORBMinorCode_65 ) sep \
 code( BAD_INV_ORDER_ErrorInDynamicImplementation  , OMNIORBMinorCode_66 ) sep \
 code( BAD_INV_ORDER_RequestConfiguredOutOfOrder   , OMNIORBMinorCode_86 ) sep \
 code( BAD_INV_ORDER_DynAnyNotInitialised          , OMNIORBMinorCode_103 ) sep \
-code( BAD_INV_ORDER_ORBNotInitialised             , OMNIORBMinorCode_120 )
+code( BAD_INV_ORDER_ORBNotInitialised             , OMNIORBMinorCode_120 ) sep \
+code( BAD_INV_ORDER_NotInitialised                , OMNIORBMinorCode_138 )
 
 enum BAD_INV_ORDER_minor {
   DECLARE_BAD_INV_ORDER_minors(DeclareValue,OMNI_COMMA)  
@@ -491,13 +523,37 @@ code( TRANSIENT_BiDirConnIsGone       	  , OMNIORBMinorCode_14 ) sep \
 code( TRANSIENT_BiDirConnUsedWithNoPOA	  , OMNIORBMinorCode_16 ) sep \
 code( TRANSIENT_ConnectionClosed      	  , OMNIORBMinorCode_17 ) sep \
 code( TRANSIENT_ObjDeactivatedWhileHolding, OMNIORBMinorCode_62 ) sep \
-code( TRANSIENT_PythonExceptionInORB      , OMNIORBMinorCode_106 )
+code( TRANSIENT_PythonExceptionInORB      , OMNIORBMinorCode_106 ) sep \
+code( TRANSIENT_Renegotiate               , OMNIORBMinorCode_135 )
 
 enum TRANSIENT_minor {
   DECLARE_TRANSIENT_minors(DeclareValue,OMNI_COMMA)  
 };
 
 
+// INTF_REPOS
+#define DECLARE_INTF_REPOS_minors(code,sep) \
+\
+code( INTF_REPOS_NotAvailable                , OMNIORBMinorCode_39 ) sep \
+code( INTF_REPOS_PrimaryInterfaceReturnedZero, OMNIORBMinorCode_68 )
+
+enum INTF_REPOS_minor {
+  DECLARE_INTF_REPOS_minors(DeclareValue,OMNI_COMMA)  
+};
+
+
+// BAD_CONTEXT
+#define DECLARE_BAD_CONTEXT_minors(code,sep) \
+\
+code( BAD_CONTEXT_NoMatchingProperty    , OMNIORBMinorCode_75 ) sep \
+code( BAD_CONTEXT_StartingScopeNotFound , OMNIORBMinorCode_76 )
+
+
+enum BAD_CONTEXT_minor {
+  DECLARE_BAD_CONTEXT_minors(DeclareValue,OMNI_COMMA)
+};
+
+
 // OBJ_ADAPTER
 #define DECLARE_OBJ_ADAPTER_minors(code,sep) \
 \
@@ -556,29 +612,6 @@ enum INV_POLICY_minor {
 };
 
 
-// INTF_REPOS
-#define DECLARE_INTF_REPOS_minors(code,sep) \
-\
-code( INTF_REPOS_NotAvailable                , OMNIORBMinorCode_39 ) sep \
-code( INTF_REPOS_PrimaryInterfaceReturnedZero, OMNIORBMinorCode_68 )
-
-enum INTF_REPOS_minor {
-  DECLARE_INTF_REPOS_minors(DeclareValue,OMNI_COMMA)  
-};
-
-
-// BAD_CONTEXT
-#define DECLARE_BAD_CONTEXT_minors(code,sep) \
-\
-code( BAD_CONTEXT_NoMatchingProperty    , OMNIORBMinorCode_75 ) sep \
-code( BAD_CONTEXT_StartingScopeNotFound , OMNIORBMinorCode_76 )
-
-
-enum BAD_CONTEXT_minor {
-  DECLARE_BAD_CONTEXT_minors(DeclareValue,OMNI_COMMA)
-};
-
-
 // TIMEOUT
 // Note that TIMEOUT_CallTimedOutOnClient is the same code as
 // TRANSIENT_CallTimedout
