@@ -9,19 +9,17 @@
 //    This file is part of the omniORB library.
 //
 //    The omniORB library is free software; you can redistribute it and/or
-//    modify it under the terms of the GNU Library General Public
+//    modify it under the terms of the GNU Lesser General Public
 //    License as published by the Free Software Foundation; either
-//    version 2 of the License, or (at your option) any later version.
+//    version 2.1 of the License, or (at your option) any later version.
 //
 //    This library is distributed in the hope that it will be useful,
 //    but WITHOUT ANY WARRANTY; without even the implied warranty of
 //    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-//    Library General Public License for more details.
+//    Lesser General Public License for more details.
 //
-//    You should have received a copy of the GNU Library General Public
-//    License along with this library; if not, write to the Free
-//    Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
-//    02111-1307, USA
+//    You should have received a copy of the GNU Lesser General Public
+//    License along with this library. If not, see http://www.gnu.org/licenses/
 //
 //
 // Description:
@@ -138,7 +136,7 @@ _CORBA_Unbounded_Sequence_w_FixSizeElement<T,elmSize,elmAlignment>::operator<<=
     }
     else if (elmSize == 8) {
 
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
       _CORBA_ULongLong* data = (_CORBA_ULongLong*)Base_T_seq::NP_data();
 
       for (_CORBA_ULong i=0; i<l; i++) {
@@ -213,7 +211,7 @@ _CORBA_Bounded_Sequence_w_FixSizeElement<T,max,elmSize,elmAlignment>::operator<<
     }
     else if (elmSize == 8) {
 
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
       _CORBA_ULongLong* data = (_CORBA_ULongLong*)Base_T_seq::NP_data();
 
       for (_CORBA_ULong i=0; i<l; i++) {
@@ -312,7 +310,7 @@ _CORBA_Sequence_Boolean::operator>>= (cdrStream& s) const
   _CORBA_ULong l = Base_T_seq::length();
   l >>= s;
   if (l==0) return;
-# if !defined(HAS_Cplusplus_Bool) || (SIZEOF_BOOL == 1)
+# if !defined(OMNI_HAS_Cplusplus_Bool) || (OMNI_SIZEOF_BOOL == 1)
   s.put_octet_array((_CORBA_Octet*)this->pd_buf,l);
 # else
   for ( _CORBA_ULong i = 0; i < l; i++ )
@@ -333,7 +331,7 @@ _CORBA_Sequence_Boolean::operator<<= (cdrStream& s)
   }
   this->length(l);
   if (l==0) return;
-# if !defined(HAS_Cplusplus_Bool) || (SIZEOF_BOOL == 1)
+# if !defined(OMNI_HAS_Cplusplus_Bool) || (OMNI_SIZEOF_BOOL == 1)
   s.get_octet_array((_CORBA_Octet*)this->pd_buf,l);
 # else
   for ( _CORBA_ULong i = 0; i < l; i++ )
@@ -504,7 +502,7 @@ _CORBA_Sequence_Array_Boolean<T,T_slice,dimension>::operator>>=(cdrStream& s) co
 {
   this->pd_len >>= s;
   if (this->pd_len==0) return;
-# if !defined(HAS_Cplusplus_Bool) || (SIZEOF_BOOL == 1)
+# if !defined(OMNI_HAS_Cplusplus_Bool) || (OMNI_SIZEOF_BOOL == 1)
   s.put_octet_array((_CORBA_Octet*)this->pd_buf,(int)this->pd_len*dimension);
 # else
   for (_CORBA_ULong i=0; i<this->pd_len; i++) {
@@ -528,7 +526,7 @@ _CORBA_Sequence_Array_Boolean<T,T_slice,dimension>::operator<<=(cdrStream& s)
   }
   this->length(l);
   if (l==0) return;
-# if !defined(HAS_Cplusplus_Bool) || (SIZEOF_BOOL == 1)
+# if !defined(OMNI_HAS_Cplusplus_Bool) || (OMNI_SIZEOF_BOOL == 1)
   s.get_octet_array((_CORBA_Octet*)this->pd_buf,(int)l*dimension);
 # else
   for (_CORBA_ULong i=0; i<l; i++) {
@@ -653,7 +651,7 @@ _CORBA_Unbounded_Sequence_Array_w_FixSizeElement<T,T_slice,Telm,dimension,elmSiz
     }
     else if (elmSize == 8) {
 
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
       _CORBA_ULongLong* data = (_CORBA_ULongLong*)Base_T_seq::NP_data();
 
       for (_CORBA_ULong i=0; i<l; i++) {
@@ -731,7 +729,7 @@ _CORBA_Bounded_Sequence_Array_w_FixSizeElement<T,T_slice,Telm,dimension,max,elmS
     }
     else if (elmSize == 8) {
 
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
       _CORBA_ULongLong* data = (_CORBA_ULongLong*)Base_T_seq::NP_data();
 
       for (_CORBA_ULong i=0; i<l; i++) {
