@@ -11,19 +11,17 @@
 //    This file is part of the omniORB library
 //
 //    The omniORB library is free software; you can redistribute it and/or
-//    modify it under the terms of the GNU Library General Public
+//    modify it under the terms of the GNU Lesser General Public
 //    License as published by the Free Software Foundation; either
-//    version 2 of the License, or (at your option) any later version.
+//    version 2.1 of the License, or (at your option) any later version.
 //
 //    This library is distributed in the hope that it will be useful,
 //    but WITHOUT ANY WARRANTY; without even the implied warranty of
 //    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-//    Library General Public License for more details.
+//    Lesser General Public License for more details.
 //
-//    You should have received a copy of the GNU Library General Public
-//    License along with this library; if not, write to the Free
-//    Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
-//    02111-1307, USA
+//    You should have received a copy of the GNU Lesser General Public
+//    License along with this library. If not, see http://www.gnu.org/licenses/
 //
 //
 // Description:
@@ -303,8 +301,13 @@ CORBA::Any::operator<<= (cdrStream& s)
   PR_clearData();
 
   grabTC(pd_tc, CORBA::TypeCode::unmarshalTypeCode(s));
-  pd_mbuf = new cdrAnyMemoryStream;
-  tcParser::copyStreamToStream(get(pd_tc), s, *pd_mbuf);
+
+  CORBA::TCKind kind = pd_tc->kind();
+
+  if (!(kind == CORBA::tk_void || kind == tk_null)) {
+    pd_mbuf = new cdrAnyMemoryStream;
+    tcParser::copyStreamToStream(get(pd_tc), s, *pd_mbuf);
+  }
 }
 
 // omniORB data-only marshalling functions
@@ -568,7 +571,7 @@ CORBA::Any::operator<<=(ULong u)
   u >>= *pd_mbuf;
 }
 
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 void
 CORBA::Any::operator<<=(LongLong l)
 {
@@ -589,7 +592,7 @@ CORBA::Any::operator<<=(ULongLong u)
 #endif
 
 
-#if !defined(NO_FLOAT)
+#if !defined(OMNI_NO_FLOAT)
 void
 CORBA::Any::operator<<=(Float f)
 {
@@ -608,7 +611,7 @@ CORBA::Any::operator<<=(Double d)
   d >>= *pd_mbuf;
 }
 
-#ifdef HAS_LongDouble
+#ifdef OMNI_HAS_LongDouble
 void
 CORBA::Any::operator<<=(LongDouble d)
 {
@@ -717,7 +720,7 @@ CORBA::Any::operator>>=(ULong& u) const
 }
 
 
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 CORBA::Boolean
 CORBA::Any::operator>>=(LongLong& l) const
 {
@@ -741,7 +744,7 @@ CORBA::Any::operator>>=(ULongLong& u) const
 #endif
 
 
-#if !defined(NO_FLOAT)
+#if !defined(OMNI_NO_FLOAT)
 CORBA::Boolean
 CORBA::Any::operator>>=(Float& f) const
 {
@@ -763,7 +766,7 @@ CORBA::Any::operator>>=(Double& d) const
   return 1;
 }
 
-#ifdef HAS_LongDouble
+#ifdef OMNI_HAS_LongDouble
 CORBA::Boolean
 CORBA::Any::operator>>=(LongDouble& d) const
 {
@@ -1444,3 +1447,25 @@ CORBA::Any::value() const
   }
   return snap_mbuf->bufPtr();
 }
+
+
+// Exception repository id
+void
+CORBA::Any::PR_marshalExceptionRepoId(cdrStream& s, const char* repo_id)
+{
+  // Exception value is preceeded by repository id, even though the id
+  // is in the TypeCode.
+  if (orbParameters::exceptionIdInAny)
+    s.marshalRawString(repo_id);
+}
+
+void
+CORBA::Any::PR_unmarshalExceptionRepoId(cdrStream& s)
+{
+  if (orbParameters::exceptionIdInAny) {
+    // We don't need the repository id. We just skip it.
+    CORBA::ULong len;
+    len <<= s;
+    s.skipInput(len);
+  }
+}
