@@ -9,19 +9,17 @@
 //    This file is part of the omniORB library
 //
 //    The omniORB library is free software; you can redistribute it and/or
-//    modify it under the terms of the GNU Library General Public
+//    modify it under the terms of the GNU Lesser General Public
 //    License as published by the Free Software Foundation; either
-//    version 2 of the License, or (at your option) any later version.
+//    version 2.1 of the License, or (at your option) any later version.
 //
 //    This library is distributed in the hope that it will be useful,
 //    but WITHOUT ANY WARRANTY; without even the implied warranty of
 //    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-//    Library General Public License for more details.
+//    Lesser General Public License for more details.
 //
-//    You should have received a copy of the GNU Library General Public
-//    License along with this library; if not, write to the Free
-//    Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-//    02111-1307, USA
+//    You should have received a copy of the GNU Lesser General Public
+//    License along with this library. If not, see http://www.gnu.org/licenses/
 //
 //
 // Description:
@@ -50,7 +48,7 @@ dealWithUserException(cdrMemoryStream& stream,
 		      CORBA::UserException& ex);
 
 
-#ifdef HAS_Cplusplus_Namespace
+#ifdef OMNI_HAS_Cplusplus_Namespace
 namespace {
 #endif
   class PostInvoker {
@@ -100,7 +98,7 @@ namespace {
     int                   pd_done;
   };
 
-#ifdef HAS_Cplusplus_Namespace
+#ifdef OMNI_HAS_Cplusplus_Namespace
 }
 #endif
 
@@ -111,6 +109,7 @@ omniCallHandle::upcall(omniServant* servant, omniCallDescriptor& desc)
   OMNIORB_ASSERT(pd_localId);
   desc.poa(pd_poa);
   desc.localId(pd_localId);
+  desc.callHandle(this);
 
   _OMNI_NS(poaCurrentStackInsert) insert(&desc, pd_self_thread);
 
@@ -189,7 +188,7 @@ omniCallHandle::upcall(omniServant* servant, omniCallDescriptor& desc)
 
 	pd_call_desc->unmarshalReturnedValues(stream);
       }
-#ifdef HAS_Cplusplus_catch_exception_by_base
+#ifdef OMNI_HAS_Cplusplus_catch_exception_by_base
       catch (CORBA::UserException& ex) {
 	stream.rewindPtrs();
 	stream.clearValueTracker();
@@ -298,7 +297,7 @@ MainThreadTask::execute()
     _OMNI_NS(poaCurrentStackInsert) insert(&pd_desc);
     pd_desc.doLocalCall(pd_servant);
   }
-#ifdef HAS_Cplusplus_catch_exception_by_base
+#ifdef OMNI_HAS_Cplusplus_catch_exception_by_base
   catch (CORBA::Exception& ex) {
     pd_except = CORBA::Exception::_duplicate(&ex);
   }
