@@ -50,7 +50,7 @@
 #include <omniIdentity.h>
 #include <SocketCollection.h>
 
-#ifdef HAVE_SIGNAL_H
+#ifdef OMNI_HAVE_SIGNAL_H
 #  include <signal.h>
 #  include <errno.h>
 #endif
@@ -915,9 +915,8 @@ public:
 			1) {}
 
 
-  void visit(const char*,orbOptions::Source)
-    OMNI_THROW_SPEC (orbOptions::BadParam)
-  {
+  void visit(const char*,orbOptions::Source) {
+
     orbOptions::sequenceString_var usage;
     usage = orbOptions::singleton().usageArgv();
 
@@ -946,9 +945,8 @@ public:
 			"-ORBid " ORB_ID_STRING " (standard option)") {}
 
 
-  void visit(const char* value,orbOptions::Source)
-    OMNI_THROW_SPEC (orbOptions::BadParam)
-  {
+  void visit(const char* value,orbOptions::Source) {
+
     if (!isValidId(value)) {
       throw orbOptions::BadParam(key(),value,"id is not " ORB_ID_STRING);
     }
@@ -979,9 +977,8 @@ public:
 			"-ORBdumpConfiguration < 0 | 1 >") {}
 
 
-  void visit(const char* value,orbOptions::Source)
-    OMNI_THROW_SPEC (orbOptions::BadParam)
-  {
+  void visit(const char* value,orbOptions::Source) {
+
     CORBA::Boolean v;
     if (!orbOptions::getBoolean(value,v)) {
       throw orbOptions::BadParam(key(),value,
@@ -1009,9 +1006,8 @@ public:
 			"-ORBlcdMode < 0 | 1 >") {}
 
 
-  void visit(const char* value,orbOptions::Source)
-    OMNI_THROW_SPEC (orbOptions::BadParam)
-  {
+  void visit(const char* value,orbOptions::Source) {
+
     CORBA::Boolean v;
     if (!orbOptions::getBoolean(value,v)) {
       throw orbOptions::BadParam(key(),value,
@@ -1040,9 +1036,7 @@ public:
 			"-ORBprincipal <GIOP 1.0 principal string>") {}
 
 
-  void visit(const char* value,orbOptions::Source)
-    OMNI_THROW_SPEC (orbOptions::BadParam)
-  {
+  void visit(const char* value,orbOptions::Source) {
     CORBA::ULong l = (CORBA::ULong)strlen(value) + 1;
     omni::myPrincipalID.length(l);
     for (CORBA::ULong i = 0; i < l; i++)
@@ -1077,9 +1071,7 @@ public:
 			"-ORBconfigFile <filename>") {}
 
 
-  void visit(const char* value,orbOptions::Source)
-    OMNI_THROW_SPEC (orbOptions::BadParam)
-  {
+  void visit(const char* value,orbOptions::Source) {
     // Do nothing -- already handled before normal arguments are processed
   }
 
@@ -1111,11 +1103,11 @@ public:
   void attach() {
 
 #if !defined(__CIAO__)
-# if defined(HAVE_SIGACTION)
+# if defined(OMNI_HAVE_SIGACTION)
 
     struct sigaction act;
     sigemptyset(&act.sa_mask);
-#  ifdef HAVE_SIG_IGN
+#  ifdef OMNI_HAVE_SIG_IGN
     act.sa_handler = SIG_IGN;
 #  else
     act.sa_handler = (void (*)())0;
@@ -1128,7 +1120,7 @@ public:
 	  "SIG_IGN handler for signal SIGPIPE. (errno = " << errno << ")\n";
       }
     }
-# elif defined(HAVE_SIGVEC)
+# elif defined(OMNI_HAVE_SIGVEC)
     struct sigvec act;
     act.sv_mask = 0;
     act.sv_handler = SIG_IGN;
@@ -1140,7 +1132,7 @@ public:
 	  "SIG_IGN handler for signal SIGPIPE. (errno = " << errno << ")\n";
       }
     }
-# endif // HAVE_SIGACTION
+# endif // OMNI_HAVE_SIGACTION
 #endif // __CIAO__
 
     orbAsyncInvoker = new omniAsyncInvoker();
