@@ -3,7 +3,7 @@
 // giopImpl12.cc              Created on: 14/02/2001
 //                            Author    : Sai Lai Lo (sll)
 //
-//    Copyright (C) 2002-2013 Apasphere Ltd
+//    Copyright (C) 2002-2015 Apasphere Ltd
 //    Copyright (C) 2001 AT&T Laboratories, Cambridge
 //
 //    This file is part of the omniORB library
@@ -76,8 +76,8 @@ public:
   static size_t outputRemaining(const giopStream*);
   static void getReserveSpace(giopStream*,omni::alignment_t,size_t);
   static void copyOutputData(giopStream*,void*, size_t,omni::alignment_t);
-  static CORBA::ULong currentInputPtr(const giopStream*);
-  static CORBA::ULong currentOutputPtr(const giopStream*);
+  static size_t currentInputPtr(const giopStream*);
+  static size_t currentOutputPtr(const giopStream*);
 
   friend class nonexistence;  // Just to make gcc shut up.
 
@@ -104,9 +104,9 @@ public:
 
   static void outputNewMessage(giopStream* g);
 
-  static void outputFlush(giopStream* g,CORBA::Boolean knownFragmentSize=0);
+  static void outputFlush(giopStream* g, CORBA::Boolean knownFragmentSize=0);
 
-  static void outputSetFragmentSize(giopStream*,CORBA::ULong);
+  static void outputSetFragmentSize(giopStream*, size_t);
 
   static inline CORBA::Boolean outputHasReachedLimit(giopStream* g) {
     return g->outEnd() == g->outputBufferStart() + 12;
@@ -155,11 +155,6 @@ giopImpl12::inputQueueMessage(giopStream* g, giopStream_Buffer* b) {
   CORBA::ULong reqid;
 
   if (mtype != GIOP::CloseConnection && mtype != GIOP::MessageError) {
-    if (b->size < 16) {
-      giopStream_Buffer::deleteBuffer(b);
-      OMNIORB_THROW(MARSHAL, MARSHAL_PassEndOfMessage,
-                    (CORBA::CompletionStatus)g->completion());
-    }
 
     // unmarshal request id.
     reqid = *((CORBA::ULong*)(hdr + 12));
@@ -524,7 +519,6 @@ giopImpl12::inputNewFragment(giopStream* g) {
 
   g->pd_inb_mkr = (void*)(hdr + 16);
   g->pd_inb_end = (void*)g->inputBufferLast();
-  OMNIORB_ASSERT(g->pd_inb_mkr <= g->pd_inb_end);
 
   g->inputExpectAnotherFragment(((hdr[6] & 0x2) ? 1 : 0));
 
@@ -608,7 +602,6 @@ giopImpl12::inputReplyBegin(giopStream* g,
 
   g->pd_inb_mkr = (void*)(hdr + 16);
   g->pd_inb_end = (void*)g->inputBufferLast();
-  OMNIORB_ASSERT(g->pd_inb_mkr <= g->pd_inb_end);
 
   g->inputExpectAnotherFragment(((hdr[6] & 0x2) ? 1 : 0));
 
@@ -989,7 +982,7 @@ giopImpl12::inputRemaining(giopStream* g) {
     return orbParameters::giopMaxMsgSize - currentInputPtr(g);
   }
   else {
-    return (g->inputFragmentToCome() + (g->inEnd() - g->inMkr()));
+    return g->inputFragmentToCome() + (g->inEnd() - g->inMkr());
   }
 }
 
@@ -1186,7 +1179,7 @@ giopImpl12::copyInputData(giopStream* g, void* b, size_t sz,
       else {
 	if (b && sz >= giopStream::directReceiveCutOff) {
 
-	  CORBA::ULong transz = g->inputFragmentToCome();
+	  size_t transz = g->inputFragmentToCome();
 	  if (transz > sz)
             transz = sz;
 
@@ -1213,13 +1206,11 @@ giopImpl12::copyInputData(giopStream* g, void* b, size_t sz,
 }
 
 ////////////////////////////////////////////////////////////////////////
-CORBA::ULong
+size_t
 giopImpl12::currentInputPtr(const giopStream* g) {
 
-  return  g->inputMessageSize() - 
-          g->inputFragmentToCome() -
-         ((omni::ptr_arith_t) g->pd_inb_end - 
-	  (omni::ptr_arith_t) g->pd_inb_mkr);
+  return (g->inputMessageSize() - g->inputFragmentToCome() -
+          (g->inEnd() - g->inMkr()));
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -1232,11 +1223,10 @@ giopImpl12::inputTerminalProtocolError(giopStream* g,
   if (omniORB::trace(1)) {
     omniORB::logger l;
     l << "From endpoint: " << g->pd_strand->connection->peeraddress()
-      << ". Detected GIOP 1.2 protocol error in input message. "
-      << omniExHelper::strip(file) << ":" << line
+      << ". Detected GIOP 1.2 protocol error in input message: "
+      << message << ". " << omniExHelper::strip(file) << ":" << line
       << ". Connection is closed.\n";
   }
-
   inputRaiseCommFailure(g, message);
 }
 
@@ -1841,10 +1831,9 @@ giopImpl12::sendLocateReply(giopStream* g,GIOP::LocateStatusType rc,
 size_t
 giopImpl12::outputRemaining(const giopStream* g) {
 
-  CORBA::ULong total = g->outputFragmentSize();
+  size_t total = g->outputFragmentSize();
   if (!total) {
-    CORBA::ULong avail = (CORBA::Long)orbParameters::giopMaxMsgSize -
-                         (CORBA::Long)currentOutputPtr(g);
+    size_t avail = orbParameters::giopMaxMsgSize - currentOutputPtr(g);
     
     // Adjust avail to exactly the same value as calculated in outputFlush().
     // See the comment in outputFlush() for the reason why.
@@ -1931,7 +1920,7 @@ giopImpl12::outputFlush(giopStream* g, CORBA::Boolean knownFragmentSize) {
     // Now determine how much space we have left.
     // If the message size has already reached orbParameters::giopMaxMsgSize,
     // outputHasReachedLimit() will return TRUE.
-    CORBA::ULong avail = orbParameters::giopMaxMsgSize - g->outputMessageSize();
+    size_t avail = orbParameters::giopMaxMsgSize - g->outputMessageSize();
 
     // Adjust avail to make sure that it a multiple of 8.
     // This preserves our invariant: g->pd_outb_end always align on 8 bytes
@@ -2073,16 +2062,14 @@ giopImpl12::copyOutputData(giopStream* g, void* b, size_t sz,
 
 
 ////////////////////////////////////////////////////////////////////////
-CORBA::ULong
+size_t
 giopImpl12::currentOutputPtr(const giopStream* g) {
 
-  CORBA::ULong fsz = (omni::ptr_arith_t) g->pd_outb_mkr - 
-                     ((omni::ptr_arith_t) g->pd_currentOutputBuffer + 
-		      g->pd_currentOutputBuffer->start);
+  size_t fsz = g->outMkr() - g->outputBufferStart();
 
   // Output offset is the sent message so far, plus the current buffer
   // minus 12 byte header.
-  CORBA::Long msz = g->outputMessageSize();
+  size_t msz = g->outputMessageSize();
   if (msz) {
     // At least one fragment has been output already; message has
     // been extended by the current fragment size minus its 16 byte
@@ -2098,7 +2085,7 @@ giopImpl12::currentOutputPtr(const giopStream* g) {
 
 ////////////////////////////////////////////////////////////////////////
 void
-giopImpl12::outputSetFragmentSize(giopStream* g,CORBA::ULong msz) {
+giopImpl12::outputSetFragmentSize(giopStream* g, size_t msz) {
 
   if (msz > orbParameters::giopMaxMsgSize) {
     OMNIORB_THROW(MARSHAL,MARSHAL_MessageSizeExceedLimitOnClient,
