@@ -529,14 +529,6 @@ giopStrand::releaseServer(IOP_S* iop_s)
       }
     }
   }
-  else if (isBiDir() && pd_state == DYING) {
-    if (omniORB::trace(25)) {
-      omniORB::logger log;
-      log << "Bi-directional strand " << (void*)this
-          << " is dying after handling a callback.\n";
-    }
-    startIdleCounter();
-  }
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -615,7 +607,7 @@ Scavenger::removeIdle(StrandList& src,StrandList& dest,
 
     if ( s->idlebeats >= 0 ) {
 
-      if (omniORB::trace(29)) {
+      if (omniORB::trace(30)) {
 	omniORB::logger log;
 	log << "Scavenger reduce idle count for strand "
 	    << (void*)s << " to " << (s->idlebeats - 1) << "\n";
@@ -815,9 +807,8 @@ public:
 			1,
 			"-ORBscanGranularity < n >= 0 sec >") {}
 
-  void visit(const char* value,orbOptions::Source)
-    OMNI_THROW_SPEC (orbOptions::BadParam)
-  {
+  void visit(const char* value,orbOptions::Source) {
+
     CORBA::ULong v;
     if (!orbOptions::getULong(value,v)) {
       throw orbOptions::BadParam(key(),value,
@@ -844,9 +835,8 @@ public:
 			1,
 			"-ORBoutConScanPeriod < n >= 0 sec >") {}
 
-  void visit(const char* value,orbOptions::Source)
-    OMNI_THROW_SPEC (orbOptions::BadParam)
-  {
+  void visit(const char* value,orbOptions::Source) {
+
     CORBA::ULong v;
     if (!orbOptions::getULong(value,v)) {
       throw orbOptions::BadParam(key(),value,
@@ -873,9 +863,8 @@ public:
 			1,
 			"-ORBinConScanPeriod < n >= 0 sec >") {}
 
-  void visit(const char* value,orbOptions::Source)
-    OMNI_THROW_SPEC (orbOptions::BadParam)
-  {
+  void visit(const char* value,orbOptions::Source) {
+
     CORBA::ULong v;
     if (!orbOptions::getULong(value,v)) {
       throw orbOptions::BadParam(key(),value,
