@@ -9,19 +9,17 @@
 //    This file is part of the omniORB library
 //
 //    The omniORB library is free software; you can redistribute it and/or
-//    modify it under the terms of the GNU Library General Public
+//    modify it under the terms of the GNU Lesser General Public
 //    License as published by the Free Software Foundation; either
-//    version 2 of the License, or (at your option) any later version.
+//    version 2.1 of the License, or (at your option) any later version.
 //
 //    This library is distributed in the hope that it will be useful,
 //    but WITHOUT ANY WARRANTY; without even the implied warranty of
 //    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-//    Library General Public License for more details.
+//    Lesser General Public License for more details.
 //
-//    You should have received a copy of the GNU Library General Public
-//    License along with this library; if not, write to the Free
-//    Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
-//    02111-1307, USA
+//    You should have received a copy of the GNU Lesser General Public
+//    License along with this library. If not, see http://www.gnu.org/licenses/
 //
 //
 // Description:
@@ -52,7 +50,7 @@ GIOP::Version orbParameters::maxGIOPVersion = { 1, 2 };
 //
 //  Valid values = 1.0 | 1.1 | 1.2
 
-CORBA::ULong orbParameters::giopMaxMsgSize = 2048 * 1024;
+size_t orbParameters::giopMaxMsgSize = 2048 * 1024;
 //   This value defines the ORB-wide limit on the size of GIOP message 
 //   (excluding the header). If this limit is exceeded, the ORB will
 //   refuse to send or receive the message and raise a MARSHAL exception.
@@ -139,12 +137,6 @@ CORBA::Boolean orbParameters::strictIIOP = 1;
 //
 //   Valid values = 0 or 1
 
-CORBA::Boolean orbParameters::immediateRopeSwitch = 0;
-//   Switch rope to use a new address immediately, rather than
-//   retrying with the existing one.
-//
-//   Valid values = 0 or 1
-
 
 ////////////////////////////////////////////////////////////////////////
 static giopStreamImpl* implHead = 0;
@@ -257,7 +249,7 @@ public:
 			1,
 			"-ORBmaxGIOPVersion < 1.0 | 1.1 | 1.2 >") {}
 
-  void visit(const char* value,orbOptions::Source) throw (orbOptions::BadParam) {
+  void visit(const char* value,orbOptions::Source) {
 
     unsigned int ma, mi;
     if ( sscanf(value, "%u.%u", &ma, &mi) != 2 || ma > 255 || mi > 255) {
@@ -286,22 +278,40 @@ public:
 
   giopMaxMsgSizeHandler() : 
     orbOptions::Handler("giopMaxMsgSize",
-			"giopMaxMsgSize = n >= 8192",
+			"giopMaxMsgSize = n >= 8192 or n == 0",
 			1,
-			"-ORBgiopMaxMsgSize < n >= 8192 >") {}
+			"-ORBgiopMaxMsgSize < n >= 8192 or n == 0 >") {}
 
-  void visit(const char* value,orbOptions::Source) throw (orbOptions::BadParam) {
+  void visit(const char* value,orbOptions::Source) {
 
-    CORBA::ULong v;
-    if (!orbOptions::getULong(value,v) || v < 8192) {
+    size_t v;
+    
+    if (!orbOptions::getSizeT(value,v) || (v && v < 8192)) {
       throw orbOptions::BadParam(key(),value,
-				 "Invalid value, expect n >= 8192");
+				 "Invalid value, expect n >= 8192 or n == 0");
+    }
+    if (v) {
+      orbParameters::giopMaxMsgSize = v;
+    }
+    else {
+      // Set to maximum signed value, to aid indirection code that
+      // calculates negative values.
+
+#if (OMNI_SIZEOF_LONG == OMNI_SIZEOF_PTR)
+      orbParameters::giopMaxMsgSize = LONG_MAX;
+#elif (OMNI_SIZEOF_INT == OMNI_SIZEOF_PTR)
+      orbParameters::giopMaxMsgSize = INT_MAX;
+#elif defined (_WIN64)
+      orbParameters::giopMaxMsgSize = _I64_MAX;
+#else
+#error "No suitable integer type available to calculate maximum" \
+  " message size"
+#endif
     }
-    orbParameters::giopMaxMsgSize = v;
   }
 
   void dump(orbOptions::sequenceString& result) {
-    orbOptions::addKVULong(key(),orbParameters::giopMaxMsgSize,
+    orbOptions::addKVSizeT(key(),orbParameters::giopMaxMsgSize,
 			   result);
   }
 
@@ -319,7 +329,7 @@ public:
 			1,
 			"-ORBclientCallTimeOutPeriod < n >= 0 in msecs >") {}
 
-  void visit(const char* value,orbOptions::Source) throw (orbOptions::BadParam) {
+  void visit(const char* value,orbOptions::Source) {
 
     CORBA::ULong v;
     if (!orbOptions::getULong(value,v)) {
@@ -350,7 +360,7 @@ public:
 			1,
 			"-ORBsupportPerThreadTimeOut < 0 | 1 >") {}
 
-  void visit(const char* value,orbOptions::Source) throw (orbOptions::BadParam) {
+  void visit(const char* value,orbOptions::Source) {
 
     CORBA::Boolean v;
     if (!orbOptions::getBoolean(value,v)) {
@@ -378,7 +388,7 @@ public:
 			1,
 			"-ORBclientConnectTimeOutPeriod < n >= 0 in msecs >") {}
 
-  void visit(const char* value,orbOptions::Source) throw (orbOptions::BadParam) {
+  void visit(const char* value,orbOptions::Source) {
 
     CORBA::ULong v;
     if (!orbOptions::getULong(value,v)) {
@@ -411,7 +421,7 @@ public:
 			1,
 			"-ORBserverCallTimeOutPeriod < n >= 0 in msecs >") {}
 
-  void visit(const char* value,orbOptions::Source) throw (orbOptions::BadParam) {
+  void visit(const char* value,orbOptions::Source) {
 
     CORBA::ULong v;
     if (!orbOptions::getULong(value,v)) {
@@ -442,7 +452,7 @@ public:
 			1,
 			"-ORBmaxInterleavedCallsPerConnection < n > 0 >") {}
 
-  void visit(const char* value,orbOptions::Source) throw (orbOptions::BadParam) {
+  void visit(const char* value,orbOptions::Source) {
 
     CORBA::ULong v;
     if (!orbOptions::getULong(value,v) || v < 1) {
@@ -474,7 +484,7 @@ public:
 			1,
 			"-ORBgiopTargetAddressMode < 0 | 1 | 2 >") {}
 
-  void visit(const char* value,orbOptions::Source) throw (orbOptions::BadParam) {
+  void visit(const char* value,orbOptions::Source) {
 
     CORBA::ULong v;
     if (!orbOptions::getULong(value,v)) {
@@ -525,7 +535,7 @@ public:
 			"-ORBstrictIIOP < 0 | 1 >") {}
 
 
-  void visit(const char* value,orbOptions::Source) throw (orbOptions::BadParam) {
+  void visit(const char* value,orbOptions::Source) {
 
     CORBA::Boolean v;
     if (!orbOptions::getBoolean(value,v)) {
@@ -543,36 +553,6 @@ public:
 
 static strictIIOPHandler strictIIOPHandler_;
 
-/////////////////////////////////////////////////////////////////////////////
-class immediateRopeSwitchHandler : public orbOptions::Handler {
-public:
-
-  immediateRopeSwitchHandler() : 
-    orbOptions::Handler("immediateAddressSwitch",
-			"immediateAddressSwitch = 0 or 1",
-			1,
-			"-ORBimmediateAddressSwitch < 0 | 1 >") {}
-
-
-  void visit(const char* value,orbOptions::Source) throw (orbOptions::BadParam) {
-
-    CORBA::Boolean v;
-    if (!orbOptions::getBoolean(value,v)) {
-      throw orbOptions::BadParam(key(),value,
-				 orbOptions::expect_boolean_msg);
-    }
-    orbParameters::immediateRopeSwitch = v;
-  }
-
-  void dump(orbOptions::sequenceString& result) {
-    orbOptions::addKVBoolean(key(),orbParameters::immediateRopeSwitch,
-			     result);
-  }
-};
-
-static immediateRopeSwitchHandler immediateRopeSwitchHandler_;
-
-
 
 /////////////////////////////////////////////////////////////////////////////
 //            Module initialiser                                           //
@@ -595,7 +575,6 @@ public:
     orbOptions::singleton().registerHandler(maxInterleavedCallsPerConnectionHandler_);
     orbOptions::singleton().registerHandler(giopTargetAddressModeHandler_);
     orbOptions::singleton().registerHandler(strictIIOPHandler_);
-    orbOptions::singleton().registerHandler(immediateRopeSwitchHandler_);
   }
 
   void attach() {
