@@ -9,19 +9,17 @@
 //    This file is part of the omniORB library
 //
 //    The omniORB library is free software; you can redistribute it and/or
-//    modify it under the terms of the GNU Library General Public
+//    modify it under the terms of the GNU Lesser General Public
 //    License as published by the Free Software Foundation; either
-//    version 2 of the License, or (at your option) any later version.
+//    version 2.1 of the License, or (at your option) any later version.
 //
 //    This library is distributed in the hope that it will be useful,
 //    but WITHOUT ANY WARRANTY; without even the implied warranty of
 //    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-//    Library General Public License for more details.
+//    Lesser General Public License for more details.
 //
-//    You should have received a copy of the GNU Library General Public
-//    License along with this library; if not, write to the Free
-//    Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-//    02111-1307, USA
+//    You should have received a copy of the GNU Lesser General Public
+//    License along with this library. If not, see http://www.gnu.org/licenses/
 //
 
 #include <omniORB4/CORBA.h>
@@ -44,6 +42,10 @@
 #include <invoker.h>
 #include <interceptors.h>
 
+#ifdef HAVE_STD
+#include <memory>
+#endif
+
 OMNI_USING_NAMESPACE(omni)
 
 
@@ -188,12 +190,15 @@ omniObjRef::_realNarrow(const char* repoId)
       {
 	omni_tracedmutex_lock sync(*omni::internalLock);
 	objref = omni::createObjRef(repoId,ior,1,_identity());
-	objref->pd_flags.forward_location = pd_flags.forward_location;
-	objref->pd_flags.type_verified = 1;
-	objref->pd_flags.object_exists = 1;
+
+        if (objref) {
+          objref->pd_flags.forward_location = pd_flags.forward_location;
+          objref->pd_flags.type_verified    = 1;
+          objref->pd_flags.object_exists    = 1;
+        }
       }
 
-      if( objref ) {
+      if (objref) {
 	target = objref->_ptrToObjRef(repoId);
 	OMNIORB_ASSERT(target);
       }
@@ -768,13 +773,23 @@ omniObjRef::_invoke(omniCallDescriptor& call_desc, CORBA::Boolean do_assert)
       }
       omni::locationForward(this,ex.get_obj()->_PR_getobj(),ex.is_permanent());
     }
-    
+#ifdef HAVE_STD
+    catch (const std::bad_alloc&) {
+      // We keep logging as simple as possible to avoid too much allocation.
+      omniORB::logs(1, "Error: invoke raised std::bad_alloc.");
+      OMNIORB_THROW(NO_MEMORY, NO_MEMORY_BadAlloc,
+                    call_desc.called() ? CORBA::COMPLETED_YES :
+                                         CORBA::COMPLETED_NO);
+    }
+#endif // HAVE_STD
+
     if (!required_retry &&
 	(retry_after_timeout || orbParameters::resetTimeOutOnRetries)) {
 
       // Reset the timeout next time around
       abs_time.assign(0,0);
     }
+    call_desc.called(0);
   }
 }
 
@@ -832,14 +847,20 @@ AsyncRequest::execute()
     log << "Asynchronous invoke '" << pd_callDescriptor->op() << "'...\n";
   }
 
-  if (pd_threadTimeout) {
-    if (pd_timeoutAbsolute)
-      omniCurrent::get()->setDeadline(pd_threadTimeout);
-    else
-      omniCurrent::get()->setTimeout(pd_threadTimeout);
-  }
-
   try {
+    if (pd_threadTimeout) {
+      omniCurrent* current = omniCurrent::get();
+
+      if (!current)
+        OMNIORB_THROW(BAD_PARAM, BAD_PARAM_PerThreadTimeoutWithNoCurrent,
+                      CORBA::COMPLETED_NO);
+
+      if (pd_timeoutAbsolute)
+        current->setDeadline(pd_threadTimeout);
+      else
+        current->setTimeout(pd_threadTimeout);
+    }
+
     pd_objref->_invoke(*pd_callDescriptor);
 
     if (omniORB::trace(25)) {
@@ -1174,7 +1195,7 @@ public:
 			"-ORBverifyObjectExistsAndType < 0 | 1 >") {}
 
 
-  void visit(const char* value,orbOptions::Source) throw (orbOptions::BadParam) {
+  void visit(const char* value,orbOptions::Source) {
 
     CORBA::Boolean v;
     if (!orbOptions::getBoolean(value,v)) {
@@ -1204,7 +1225,7 @@ public:
 			"-ORBcopyValuesInLocalCalls < 0 | 1 >") {}
 
 
-  void visit(const char* value,orbOptions::Source) throw (orbOptions::BadParam) {
+  void visit(const char* value,orbOptions::Source) {
 
     CORBA::Boolean v;
     if (!orbOptions::getBoolean(value,v)) {
@@ -1234,7 +1255,7 @@ public:
 			"-ORBresetTimeOutOnRetries < 0 | 1 >") {}
 
 
-  void visit(const char* value,orbOptions::Source) throw (orbOptions::BadParam) {
+  void visit(const char* value,orbOptions::Source) {
 
     CORBA::Boolean v;
     if (!orbOptions::getBoolean(value,v)) {
